import os


PATH_USER_PROJECT_DIR = os.path.join(os.getcwd(),'.pureml')

PATH_CONFIG = os.path.join(PATH_USER_PROJECT_DIR,'config.pkl')# 'temp.yaml'

PATH_ARTIFACT_DIR = os.path.join(PATH_USER_PROJECT_DIR,'artifacts')
PATH_ARRAY_DIR = os.path.join(PATH_USER_PROJECT_DIR,'array')
PATH_AUDIO_DIR = os.path.join(PATH_USER_PROJECT_DIR,'audio')
PATH_FIGURE_DIR = os.path.join(PATH_USER_PROJECT_DIR,'figure')
PATH_TABULAR_DIR = os.path.join(PATH_USER_PROJECT_DIR,'tabular')
PATH_VIDEO_DIR = os.path.join(PATH_USER_PROJECT_DIR,'video')
PATH_IMAGE_DIR = os.path.join(PATH_USER_PROJECT_DIR,'image')

PATH_DATASET_DIR = os.path.join(PATH_USER_PROJECT_DIR,'dataset')
PATH_MODEL_DIR = os.path.join(PATH_USER_PROJECT_DIR,'model')
PATH_USER_TOKEN =  os.path.join(os.path.expanduser('~'), '.pureml/token')
PATH_USER_PROJECT = os.path.join(PATH_USER_PROJECT_DIR,'pure.project')

# BASE_URL = 'https://dev-api.pureml.com'
BASE_URL = 'https://api.pureml.com'





from pureml.components.dataset import register
from pureml.utils.pipeline import add_dataset_to_config
from pureml.pipeline.data.create_pipeline import create_pipeline

def dataset(name:str, parent:str=None, upload=False):

    def decorator(func):
        # print('Inside decorator')


        add_dataset_to_config(name=name, parent=parent)
        
        def wrapper(*args, **kwargs):
            # print("Inside wrapper")
            
            func_output = func(*args, **kwargs)
            # print(func_output)


            pipeline = create_pipeline()

            if not upload:
                dataset = None
            else:
                dataset = func_output

            dataset_exists_in_remote, dataset_hash, dataset_version = register(dataset=dataset, name=name, pipeline=pipeline)


            if dataset_exists_in_remote:
                add_dataset_to_config(name=name, hash=dataset_hash, version=dataset_version, parent=parent)

            return func_output

        # print("Outside  wrapper")

        return wrapper
    # print('Outside decorator')
        
    return decorator